import { useData } from './useData';
import { AxisBottom, AxisLeft } from './Axes';
import { Marks } from './Marks';
import { scaleLinear, format, extent, timeFormat, scaleTime, axisBottom } from 'd3';

const width = 960;
const height = 500;
const margin = {
  top: 50,
  right: 30,
  bottom: 65,
  left: 90,
};

const innerHeight =
  height - margin.top - margin.bottom;
const innerWidth =
  width - margin.left - margin.right;
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;
const xTextOffset = 20;

export const ConnectedScatterPlot = () => {
  let data = useData();
  if (!data) {
    return <pre>Loading...</pre>;
  }

const xAxisTickFormat = (tickValue) =>
    timeFormat('%B - %Y')(tickValue);

    const siFormat = format('.2s');
  const yAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');
  
  const xValue = (d) => d.Time;
  console.log(xValue);

  const xAxisLabel = 'Time';
  const yValue = (d) => d.Value;
  const yAxisLabel = 'Value';

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain([0, 100])
    .range([innerHeight,0]);

  const colorDot = (value) => {
    if (value > 75) {
      return 'mark-red';
    } 
    else if(value > 50)
    {
     return 'mark-amber';
    }
    else {
      return 'mark-green';
    }
  };
 
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        /* X-Axis */
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          textOffset={xTextOffset}
          axisBottom = {axisBottom}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        /* X-Axis */ /* Y-Axis */
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${
            innerHeight / 2
          }) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
 
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={5}
        />
        /* Y-Axis */ /* data points */
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          colorDot={colorDot}
          tooltipFormat={yAxisTickFormat}
          circleRadius={7}
        />
        /* data points */
      </g>
    </svg>
  );
};
